@@ -8,7 +8,7 @@ from .factories import UserFactory
 class APIRequestTestCase(TestCase):
     user_factory = UserFactory
 
-    def create_request(self, method='get', *, url='/', user=None, auth=True, **kwargs):
+    def create_request(self, method='get', url='/', user=None, auth=True, **kwargs):
         if not user:
             if auth:
                 user = self.user_factory.create()
